<?php

return [
    'Names' => [
        'ADP' => [
            0 => 'ADP',
            1 => 'اؠڑورَن پیسِٹا',
        ],
        'AED' => [
            0 => 'AED',
            1 => 'مُتحدہ عرب اِمارات دِرہم',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'افغان افغٲنی',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'اؠلبینِیَن لِک',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'اَرمانؠن ڈرؠم',
        ],
        'ANG' => [
            0 => 'ANG',
            1 => 'نایدَرلینڑ اؠنٹٕلیٖیَن گِلڑَر',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'اؠنگولَن کوانزا',
        ],
        'AOR' => [
            0 => 'AOR',
            1 => 'اؠنگولَن کوانزا رؠجِسٹاڑو',
        ],
        'ARA' => [
            0 => 'ARA',
            1 => 'أرجَنٹیٖن اَسٹرل',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'أرجَنٹیٖن پِسو',
        ],
        'ATS' => [
            0 => 'ATS',
            1 => 'آسٹریَن شِلِنگ',
        ],
        'AUD' => [
            0 => 'A$',
            1 => 'آسٹریلِیَن ڈالَر',
        ],
        'AWG' => [
            0 => 'AWG',
            1 => 'اَروبَن فِلورِن',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'آزَرباجانی مَنَٹ',
        ],
        'BAD' => [
            0 => 'BAD',
            1 => 'بوزنِیاہَرزِگووِنا دیٖنار',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'بوزنِیاہَرزِگووِنا کَنوٲٹیبٕل مارٕک',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'بابیڑِیَن ڈالَر',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'بَنگلادیٖشی ٹَکا',
        ],
        'BEF' => [
            0 => 'BEF',
            1 => 'بَلجِیَن فرینک',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'بیلگیرِیَن ہاڑ لِو',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'بحریٖنی دیٖنار',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'بُرُنڑِین فرینک',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'بٔرمیوٗڑَن ڈالَر',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'برونی ڈالَر',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'بولِوِیَن بولوینو',
        ],
        'BOP' => [
            0 => 'BOP',
            1 => 'بولویَن پِسو',
        ],
        'BOV' => [
            0 => 'BOV',
            1 => 'بولوِیَن مَوڈال',
        ],
        'BRB' => [
            0 => 'BRB',
            1 => 'برازیٖلین کروزِرو نووو',
        ],
        'BRC' => [
            0 => 'BRC',
            1 => 'برازیٖلین کروزیڑو',
        ],
        'BRE' => [
            0 => 'BRE',
            1 => 'برازیٖلین کروزِرو',
        ],
        'BRL' => [
            0 => 'R$',
            1 => 'برازیٖلی رِیَل',
        ],
        'BRN' => [
            0 => 'BRN',
            1 => 'برازیٖلین کروزیڑو نووو',
        ],
        'BRR' => [
            0 => 'BRR',
            1 => 'برازیٖلین کروزیرو',
        ],
        'BSD' => [
            0 => 'BSD',
            1 => 'بہامِیَن ڈالر',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'بوٗٹینیٖز نگُلٹرم',
        ],
        'BUK' => [
            0 => 'BUK',
            1 => 'بٔرمیٖز کیٹ',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'بوٹٕسوانَن پُلا',
        ],
        'BYB' => [
            0 => 'BYB',
            1 => 'بِلیروشِیَن نِو رِبٕل',
        ],
        'BYN' => [
            0 => 'BYN',
            1 => 'بِلیروشِیَن رِبٕل',
        ],
        'BYR' => [
            0 => 'BYR',
            1 => 'بِلیروشِیَن رِبٕل (۲۰۰۰–۲۰۱۶)',
        ],
        'BZD' => [
            0 => 'BZD',
            1 => 'بِلِزی ڈالر',
        ],
        'CAD' => [
            0 => 'CA$',
            1 => 'کینَڑِیَن ڈالر',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'کونگولیٖز فریک',
        ],
        'CHE' => [
            0 => 'CHE',
            1 => 'وِر یوٗرو',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'سُوِز فریک',
        ],
        'CHW' => [
            0 => 'CHW',
            1 => 'وِر فریک',
        ],
        'CLF' => [
            0 => 'CLF',
            1 => 'چِلِن یوٗنِڑیدیٖز ڑِ فومیٹو',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'چِلِن پِسو',
        ],
        'CNY' => [
            0 => 'CN¥',
            1 => 'چیٖنی یُوان',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'کولَمبِین پِسو',
        ],
        'COU' => [
            0 => 'COU',
            1 => 'ِٖیوٗنِڑیڑ ڑِ ویلور رِیل',
        ],
        'CRC' => [
            0 => 'CRC',
            1 => 'کوسٹا رِکَن کولَن',
        ],
        'CSD' => [
            0 => 'CSD',
            1 => 'پرون سٔربِین ڈالر',
        ],
        'CSK' => [
            0 => 'CSK',
            1 => 'چِکوسولوواک ہاڑ کوروٗنا',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'کیوٗبَن پِسو',
        ],
        'CYP' => [
            0 => 'CYP',
            1 => 'کیپروٹ پَوُڑ',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'چیک کوریٖنا',
        ],
        'DDM' => [
            0 => 'DDM',
            1 => 'مٔشرِقی جٔرمَن مارٕک',
        ],
        'DEM' => [
            0 => 'DEM',
            1 => 'جٔرمَن مارٕک',
        ],
        'DKK' => [
            0 => 'DKK',
            1 => 'ڈٔنِش کرون',
        ],
        'DOP' => [
            0 => 'DOP',
            1 => 'ڈومِنِکَن پِسو',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'اؠلجیرِیَن ڈیٖنار',
        ],
        'EEK' => [
            0 => 'EEK',
            1 => 'اؠسٹونِیَن کرون',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'اِجِپٹِیَن پَوُنڑ',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'رِٹریٖن نَفکا',
        ],
        'ESP' => [
            0 => 'ESP',
            1 => 'سِپینِش پیسِٹا',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'اِتھوپِیَن بِر',
        ],
        'EUR' => [
            0 => '€',
            1 => 'یوٗرو',
        ],
        'FIM' => [
            0 => 'FIM',
            1 => 'فِنِش مارکا',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'فِجین ڈالر',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'فیکلینڑِس آیلینڑ پونڑ',
        ],
        'FRF' => [
            0 => 'FRF',
            1 => 'فرانسِسی فریک',
        ],
        'GBP' => [
            0 => '£',
            1 => 'برطٲنوی پوٗنڈ',
        ],
        'GEK' => [
            0 => 'GEK',
            1 => 'جارجِیَن کیوٗپَن لَرِٹ',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'جارجِیَن لاری',
        ],
        'GHC' => [
            0 => 'GHC',
            1 => 'گَنییَن سؠڑی(۱۹۷۹–۲٠٠۷)',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'گَنییَن سؠڑی',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'گِبریلٹَر پَاونڑ',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'گیمبِیاہُک دلاسی',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'گِنِیَن فرینک',
        ],
        'GNS' => [
            0 => 'GNS',
            1 => 'گِنِیَن سِلی',
        ],
        'GQE' => [
            0 => 'GQE',
            1 => 'اِکویٹورِیَل گِنِیَن اؠکویٖل',
        ],
        'GRD' => [
            0 => 'GRD',
            1 => 'گریٖسُک ڑرؠکما',
        ],
        'GTQ' => [
            0 => 'GTQ',
            1 => 'گواٹَمالَن قیوٗٹزَل',
        ],
        'GWE' => [
            0 => 'GWE',
            1 => 'پورتگیٖزُک گِنی اؠسکیوٗڑو',
        ],
        'GWP' => [
            0 => 'GWP',
            1 => 'گِنی بِساوُک پؠسو',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'گَیَنیٖزُک ڑالَر',
        ],
        'HKD' => [
            0 => 'HK$',
            1 => 'حانگ کانگُک ڑالَر',
        ],
        'HNL' => [
            0 => 'HNL',
            1 => 'حونڑورنُک لؠمپیٖرا',
        ],
        'HRD' => [
            0 => 'HRD',
            1 => 'کروایشنُک دیٖنار',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'کروایشنُک کوٗنا',
        ],
        'HTG' => [
            0 => 'HTG',
            1 => 'حیشَنُک گوڑ',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'حَنگیرِیَن فورِنٹ',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'اِنڑونیشیاہُک رُپِیاہ',
        ],
        'IEP' => [
            0 => 'IEP',
            1 => 'اَیرلینڑُک پاونڑ',
        ],
        'ILP' => [
            0 => 'ILP',
            1 => 'اِزرٲیِلی پاونڑ',
        ],
        'ILS' => [
            0 => '₪',
            1 => 'اِزرٲیِلی نٔوۍ شؠقٕل',
        ],
        'INR' => [
            0 => '₹',
            1 => 'ہِندُستٲنۍ رۄپَے',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'ایٖراقُک دیٖنار',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'ایٖرانُک رِیال',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'اَیسلینڑُک کرونا',
        ],
        'ITL' => [
            0 => 'ITL',
            1 => 'اِٹلیٖ یُک لیٖرا',
        ],
        'JMD' => [
            0 => 'JMD',
            1 => 'جَمَیکاہُک ڑالَر',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'جَرڑینیاہُک دیٖنار',
        ],
        'JPY' => [
            0 => '¥',
            1 => 'جاپانُک یَن',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'کؠنیَن شِلِنگ',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'کِرگِستانُک سوم',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'کَمبوڑِیاہُک رِیال',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'کومورِیَن فرینک',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'جنوٗبی کورِیَن وَن',
        ],
        'KRW' => [
            0 => '₩',
            1 => 'ساوتھ کورِیَن وَن',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'قُویتُک دیٖنار',
        ],
        'KYD' => [
            0 => 'KYD',
            1 => 'کیمین ججیٖرُک ڑالَر',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'کزاکِستان ٹینج',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'لَوٹِیَن کِپ',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'لیبنیٖزُک پاونڑ',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'سری لَنکاہٕچ رۄپَے',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'لَیبیرِیَن ڑالَر',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'لِسوتھو لوٹی',
        ],
        'LTL' => [
            0 => 'LTL',
            1 => 'لِتھوینِیَن لِٹاس',
        ],
        'LTT' => [
            0 => 'LTT',
            1 => 'لِتھوینِیَن ٹؠلوناس',
        ],
        'LUC' => [
            0 => 'LUC',
            1 => 'لَکزٕمبورگِیَن کَنؤرٹِبٕل فرینک',
        ],
        'LUF' => [
            0 => 'LUF',
            1 => 'لَکزٕمبورگِیَن فرینک',
        ],
        'LUL' => [
            0 => 'LUL',
            1 => 'لَکزٕمبوگ فَینانشَل فرینک',
        ],
        'LVL' => [
            0 => 'LVL',
            1 => 'لَتوِیَن لیٹس',
        ],
        'LVR' => [
            0 => 'LVR',
            1 => 'لَتوِیَن رَبٕل',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'لِبیَن دیٖنار',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'موروکَن دِرہَم',
        ],
        'MAF' => [
            0 => 'MAF',
            1 => 'موروکَن فرینک',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'مولڑووین لیوٗ',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'مؠلؠگیسی اؠریَری',
        ],
        'MGF' => [
            0 => 'MGF',
            1 => 'مؠلؠگیسی فرینک',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'مؠکَڑونِیَن دیٖنار',
        ],
        'MLF' => [
            0 => 'MLF',
            1 => 'میلِیَن فرینک',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'مِیانما کیاٹ',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'مۄنگولِیَن ٹُگرِک',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'مؠکانیٖز پَٹاکا',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'مورِٹینِیَن عوگیوٗیا (1973–2017)',
        ],
        'MRU' => [
            0 => 'MRU',
            1 => 'مورِٹینِیَن عوگیوٗیا',
        ],
        'MTL' => [
            0 => 'MTL',
            1 => 'مالٹیٖزُک لیٖرا',
        ],
        'MTP' => [
            0 => 'MTP',
            1 => 'مالٹیٖزُک پاونڑ',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'مورؠشِیاہٕچ رۄپَے',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'مالدِیٖوِیَن رُفِیا',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'مؠلیوِیَن کواچا',
        ],
        'MXN' => [
            0 => 'MX$',
            1 => 'مؠکسِکَن پؠسو',
        ],
        'MXP' => [
            0 => 'MXP',
            1 => 'مؠکسِکَن سِلوَر پؠسو (۱۸۶۱–۱۹۹۲)',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'مَلیشِیَن رِنگِٹ',
        ],
        'MZE' => [
            0 => 'MZE',
            1 => 'موزیمبِکَن سکیوٗڑو',
        ],
        'MZM' => [
            0 => 'MZM',
            1 => 'پرون موزیمبِکَن مؠٹِکَل',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'موزیمبِکَن مؠٹِکَل',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'نامِبِیَن ڑالَر',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'نَیجیرِیَن ڑالَر',
        ],
        'NIC' => [
            0 => 'NIC',
            1 => 'نِکؠراگُوؠن کورڑوبا',
        ],
        'NIO' => [
            0 => 'NIO',
            1 => 'نِکؠراگُوؠن کورڑوبا اورو',
        ],
        'NLG' => [
            0 => 'NLG',
            1 => 'ڈَچ گِلڑَر',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'نوروییِنُک کرون',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'نیپالٕچ رۄپَے',
        ],
        'NZD' => [
            0 => 'NZ$',
            1 => 'نِوزیٖلینڑُک ڑالَر',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'اومِنی رِیال',
        ],
        'PAB' => [
            0 => 'PAB',
            1 => 'پانامانِیَن بالبوز',
        ],
        'PEI' => [
            0 => 'PEI',
            1 => 'پٔریوٗوِیَن اِنٹی',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'پٔریوٗوِیَن سولٕز',
        ],
        'PES' => [
            0 => 'PES',
            1 => 'پٔریوٗوِیَن سول (۱۸۶۳–۱۹۶۵)',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'نیوٗ پیپُعا گِنِیَن کیٖنا',
        ],
        'PHP' => [
            0 => '₱',
            1 => 'پھِلِپایِٔن پؠسو',
        ],
        'PKR' => [
            0 => 'PKR',
            1 => 'پاکِستٲنۍ رۄپَے',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'پولِش زلوٹی',
        ],
        'PLZ' => [
            0 => 'PLZ',
            1 => 'پولِش زلوٹی(۱۹۵٠–۱۹۹۵)',
        ],
        'PTE' => [
            0 => 'PTE',
            1 => 'پورتُگیٖز اؠسکیوٗڑو',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'پؠرؠگیوٗوَیَن گُعارانی',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'قطاری رِیال',
        ],
        'RHD' => [
            0 => 'RHD',
            1 => 'رھوڑیشِیَن ڑالَر',
        ],
        'ROL' => [
            0 => 'ROL',
            1 => 'اولڑ رومانِیَن لؠیوٗ',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'رومانِیَن لؠیوٗ',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'سٔربِیَن دیٖنار',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'روٗسی رَبٕل',
        ],
        'RUR' => [
            0 => 'RUR',
            1 => 'رٔشیَن رَبٕل(۱۹۹۱–۱۹۹۸)',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'روانڑَن فرانک',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'سودیٖیُک رِیال',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'سولَمَن جٔزیٖرُک ڈالَر',
        ],
        'SDD' => [
            0 => 'SDD',
            1 => 'پرون سوٗڈانُک دیٖنار',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'سوٗڈانُک پونڈ',
        ],
        'SDP' => [
            0 => 'SDP',
            1 => 'پرون سوٗڈانُک پونڈ',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'سویٖڈِش کَرونا',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'سِنگاپورُک ڈالَر',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'سینٹ ہیلِنا پونڈ',
        ],
        'SIT' => [
            0 => 'SIT',
            1 => 'سلووینُک ٹولَر',
        ],
        'SKK' => [
            0 => 'SKK',
            1 => 'سلووَک کَرونا',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'سومالی شِلِنگ',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'سُریٖنامُک ڈالَر',
        ],
        'SRG' => [
            0 => 'SRG',
            1 => 'سُریٖنام گِلدَر',
        ],
        'SUR' => [
            0 => 'SUR',
            1 => 'سوویت روبٕل',
        ],
        'SVC' => [
            0 => 'SVC',
            1 => 'سَلویدَرُک کولَن',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'سیٖریاہُک پونڈ',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'سوازی لِلَنگینی',
        ],
        'THB' => [
            0 => 'THB',
            1 => 'تھایھک بات',
        ],
        'TJR' => [
            0 => 'TJR',
            1 => 'تاجکِستانُک رَبٕل',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'تاجِکتانُک سَمونی',
        ],
        'TMM' => [
            0 => 'TMM',
            1 => 'تُکَمَنِستانُک مَنَت',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'ٹُنیشیاہُک دیٖنار',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'ٹونگَن پانگا',
        ],
        'TPE' => [
            0 => 'TPE',
            1 => 'ٹیموریسو ایکیٖڈو',
        ],
        'TRL' => [
            0 => 'TRL',
            1 => 'پرون تُرکِش لیرا',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'تُرکیہُک لیرا',
        ],
        'TTD' => [
            0 => 'TTD',
            1 => 'ٹرِنہِ ڈیڈ تہٕ ٹوبیگو ڈالَر',
        ],
        'TWD' => [
            0 => 'NT$',
            1 => 'نۆو تیوانُک ڈالَر',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'تَنزانیاہُک شِلِنگ',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'یوٗکرینیاہُک ہرِوِنیا',
        ],
        'UAK' => [
            0 => 'UAK',
            1 => 'یوٗکرینیاہُک کاربووَنیٹس',
        ],
        'UGS' => [
            0 => 'UGS',
            1 => 'اُگاداہُک شِلِنگ(۱۹۶۶–۱۹۸۷)',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'اُگاداہُک شِلِنگ',
        ],
        'USD' => [
            0 => '$',
            1 => 'US ڈالر',
        ],
        'USN' => [
            0 => 'USN',
            1 => 'یوٗ ایس ڈالَر(پَگاہ)',
        ],
        'USS' => [
            0 => 'USS',
            1 => 'یوٗ ایس ڈالَر(تَمی دًۄہ)',
        ],
        'UYI' => [
            0 => 'UYI',
            1 => 'اُرگایَن پیسو یوٗنِڈیڈَس اِنڈیکسَس',
        ],
        'UYP' => [
            0 => 'UYP',
            1 => 'اُرگایَن پیسو(۱۹۷۵–۱۹۹۳)',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'اُروٗگایَن پیسو',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'اُبیکِستان سوم',
        ],
        'VEB' => [
            0 => 'VEB',
            1 => 'وینٕزوٗلیُک بولِوَر (۱۸۷۱–۲۰۰۸)',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'وینٕزوٗلیُک بولِوَر (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'وینٕزوٗلیُک بولِوَر',
        ],
        'VND' => [
            0 => '₫',
            1 => 'وِیَنَمُک ڈانگ',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'وَنوٗاَتوٗ وَتوٗ',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'سَمون تَلا',
        ],
        'XAF' => [
            0 => 'FCFA',
            1 => 'سی ایف اے فرینک بی ایٖ اے سی',
        ],
        'XCD' => [
            0 => 'EC$',
            1 => 'مَشرِقی کیرِبِیَن ڈالَر',
        ],
        'XEU' => [
            0 => 'XEU',
            1 => 'یوٗرپی کَرَنسی یوٗنِٹ',
        ],
        'XFO' => [
            0 => 'XFO',
            1 => 'فرینچ گولڈ فرینک',
        ],
        'XFU' => [
            0 => 'XFU',
            1 => 'فرینچ یوٗ اے سی فرینک',
        ],
        'XOF' => [
            0 => 'F CFA',
            1 => 'سی ایف اے فرینک بی سی ایٖ اے او',
        ],
        'XPF' => [
            0 => 'CFPF',
            1 => 'سی ایف پی فرینک',
        ],
        'XRE' => [
            0 => 'XRE',
            1 => 'آر آے این ایٖ ٹی فَنڈ',
        ],
        'YDD' => [
            0 => 'YDD',
            1 => 'یَمنُک دیٖنار',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'یَمنُک رِیال',
        ],
        'YUD' => [
            0 => 'YUD',
            1 => 'یوگوسلاوِیَن ہاڑ دیٖنار',
        ],
        'YUM' => [
            0 => 'YUM',
            1 => 'یوگوسلاوِیَن نووِے دیٖنار',
        ],
        'YUN' => [
            0 => 'YUN',
            1 => 'یوگوسلاوِیَن کَنؤٹِبٕل دیٖنار',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'ساوُتھ افریٖکاہُک رینڈ',
        ],
        'ZMK' => [
            0 => 'ZMK',
            1 => 'زِمبابیُک کواچا (1968–2012)',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'زِمبابیُک کواچا',
        ],
        'ZRN' => [
            0 => 'ZRN',
            1 => 'زایرِیَن نِو زایِر',
        ],
        'ZRZ' => [
            0 => 'ZRZ',
            1 => 'زَیرُک ڈالَر',
        ],
        'ZWD' => [
            0 => 'ZWD',
            1 => 'زِمبابِیُک ڈالَر',
        ],
    ],
];
